==> src_release_V2.8.tar.gz: dserver/system/xdr/src/bpss_xdr.c <==
static char RcsId[] =
"@(#)$Header: /segfs/dserver/dev/system/xdr/src/RCS/bpss_xdr.c,v 5.18 1999/07/08 14:10:46 goetz Rel $";

/*+*******************************************************************

 File:          bpss_xdr.c

 Project:       Device Servers with sun-rpc

 Description:   xdr_routines for bpss powersupply types.

 Author(s):     Jean Michel Chaize

 Original:      December 1991

$Revision: 5.18 $
$Date: 1999/07/08 14:10:46 $

$Author: goetz $

$Log: bpss_xdr.c,v $
Revision 5.18  1999/07/08 14:10:46  goetz
changed _LPfd_set type for Linux in macros.h

Revision 5.17  1998/05/25 17:59:38  klotz
fixed C++ prototypes in api_xdr.h

Revision 5.16  1998/04/29 10:24:00  goetz
macros.h - added __STDCPP__ for HP C++ compiler (aCC)

 * Revision 5.15  97/12/01  15:16:06  15:16:06  klotz (W.D. Klotz)
 * WIN_NT_95_released_NOV_97
 * 
 * Revision 4.34  97/01/30  13:58:36  13:58:36  goetz (Andy Goetz)
 * removed dev_printdebug() from DevXdrKernel.h
 * 
 * Revision 4.33  97/01/09  10:08:41  10:08:41  goetz (Andy Goetz)
 * (xdrproc_t) castings added to maxe_xdr, ram_xdr, thc_xdr, seism_xdr
 * 
 * Revision 4.32  97/01/08  16:48:30  16:48:30  goetz (Andy Goetz)
 * Ported to Linux (2.0.9)
 * 
Revision 4.31  1996/11/18 17:28:46  goetz
Check

 * Revision 4.28  96/10/21  16:22:20  16:22:20  taurel (E.Taurel)
 * Check_in_after_port_to_OS9/ISP_2.1_and_OS9/RPC1.4
 * 
 * Revision 4.27  96/09/17  16:39:56  16:39:56  klotz (W.D. Klotz)
 * WD Klotz: tested NT build  
 * 
 * Revision 4.26  96/07/19  10:01:00  10:01:00  taurel (E.Taurel)
 * Some_change_in_macros.h_for_the_API_port_to_OS-9_Ultra_C++
 * 
 * Revision 4.25  96/06/07  16:23:04  16:23:04  meyer (J.Meyer)
 * Corrected_elif_to_else_in_macros.h
 * 
 * Revision 4.24  96/06/05  15:01:37  15:01:37  meyer (J.Meyer)
 * Corrected_macros.h
 * 
 * Revision 4.23  96/06/03  13:10:16  13:10:16  meyer (J.Meyer)
 * Cleaned-up_MSDOS_and_added_porting_options_for_Windows_NT.
 * 
 * Revision 4.22  96/05/23  11:07:24  11:07:24  taurel (E.Taurel)
 * Added_some_definitions_for_C++_in_API_xdr.h_file
 * 
 * Revision 4.21  96/05/06  18:37:36  18:37:36  meyer (J.Meyer)
 * Fortran_compatibility_for:_dev_xdr.h,macros.h,maxe_xdr.h
 * 
 * Revision 4.20  96/02/27  13:31:36  13:31:36  meyer (J.Meyer)
 * Deleted_Cross_References_To_DSAPI_Library
 * 
 * Revision 4.19  96/01/11  17:40:21  17:40:21  meyer (Jens Meyer)
 * Added_#define_PORTMAP_to_macros.h.
 * 
 * Revision 4.18  95/12/21  10:33:28  10:33:28  meyer (Jens Meyer)
 * Corrected length calculation for D_VAR_MSTATARR.
 * 
 * Revision 4.17  95/08/02  16:05:13  16:05:13  meyer (Jens Meyer)
 * Corrected DevXdrKernel.h after C++ implementation.
 * 
 * Revision 4.15  95/03/02  10:27:51  10:27:51  meyer (Jens Meyer)
 * Added D_VAR_SFRPARR type to the kernel.
 * 
 * Revision 4.14  95/02/20  09:56:39  09:56:39  meyer (Jens Meyer)
 * Passed the compilers for HPUX, SUNOS and UCC after the first windows check in.
 * 
 * Revision 4.13  95/02/10  17:18:56  17:18:56  meyer (Jens Meyer)
 * Deleted
 * 
 * Revision 4.12  95/02/01  14:26:46  14:26:46  klotz (W.D. Klotz)
 * WDK: first successfull compile of dbase, api, xdr on WIN16/3.1
 * 
 * Revision 4.11  95/01/03  13:19:18  13:19:18  meyer (Jens Meyer)
 * Repared bug in dev_cmd_query() for version 3!
 * 
 * Revision 4.10  94/12/08  15:24:50  15:24:50  meyer (Jens Meyer)
 * Changed _manager_data in API_xdr and added old version to API_xdr_vers3.
 * 
 * Revision 4.9  94/11/28  17:04:11  17:04:11  meyer (Jens Meyer)
 * Data types for compatibility with library version 3.x
 * 
 * Revision 4.8  94/08/16  16:59:27  16:59:27  meyer (Jens Meyer)
 * Corrected error in ws_xdr.h
 * 
 * Revision 4.7  94/08/16  16:34:23  16:34:23  meyer (Jens Meyer)
 * Added define for MAX_RESOURCE_FIELD_LENGTH to macros.h
 * 
 * Revision 4.6  94/08/12  15:07:37  15:07:37  meyer (Jens Meyer)
 * Added valriable arguments to all API RPC structures.
 * 
 * Revision 4.5  94/07/20  18:15:39  18:15:39  meyer (Jens Meyer)
 * Changed include files in macros.h!
 * 
 * Revision 4.4  94/07/20  08:55:38  08:55:38  meyer (Jens Meyer)
 * All XDR functions with prototypes!
 * 
 * Revision 4.3  94/07/18  18:50:49  18:50:49  meyer (Jens Meyer)
 * Had to change macros.h, because #define must be in the first column!
 * 
 * Revision 4.2  94/07/18  18:22:05  18:22:05  meyer (Jens Meyer)
 * First test with PC macros for the XDR kernel.
 * 
 * Revision 4.1  94/05/02  10:50:42  10:50:42  meyer (Jens Meyer)
 * For Security System without connection count.
 * 
 * Revision 4.0  94/03/14  18:17:26  18:17:26  meyer (Jens Meyer)
 * Library version with Security System.
 * 
 * Revision 3.50  94/03/12  14:36:20  14:36:20  meyer (Jens Meyer)
 * Changed API xdr structures for security.
 * 
 * Revision 3.35  94/03/03  10:52:04  10:52:04  taurel (Emmanuel TAUREL)
 * Added unsigned long array type in the XDRkernel
 * 
 * Revision 3.34  94/03/03  10:28:57  10:28:57  taurel (Emmanuel TAUREL)
 * Added the unsigned long array type in
 * XDR kernel (LC and ET).
 * 
 * Revision 3.33  94/01/12  16:34:19  16:34:19  meyer (Jens Meyer)
 * Global XDR type array for data collector access
 * 
 * Revision 3.31  93/12/02  09:38:53  09:38:53  meyer (Jens Meyer)
 * New release with small XDR data type kernel.
 * 
 * Revision 1.1  93/11/16  10:55:03  10:55:03  meyer (Jens Meyer)
 * Initial revision
 * 

Copyright (c) 1990 by European Synchrotron Radiation Facility,
		      Grenoble, France
*******************************************************************-*/

#include <dev_xdr.h>
#include <bpss_xdr.h>


bool_t xdr_DevStateIndic(xdrs, objp)
	XDR *xdrs;
	DevStateIndic *objp;
{
	if (!xdr_short(xdrs, &objp->State))  return (FALSE);
	if (!xdr_short(xdrs, &objp->Indic))  return (FALSE);
	return (TRUE);
}

long
xdr_length_DevStateIndic(objp)
	DevStateIndic *objp;
{
        long  length = 0;

	length = length + xdr_length_DevShort (&objp->State);
	length = length + xdr_length_DevShort (&objp->Indic);

	return (length);
}




bool_t xdr_DevBpssState(xdrs, objp)
        XDR *xdrs;
	DevBpssState *objp;
{
        if (!xdr_short(xdrs, &objp->Ac))  return (FALSE);
        if (!xdr_short(xdrs, &objp->Dc))  return (FALSE);
        return (TRUE);
}

long
xdr_length_DevBpssState(objp)
	DevBpssState *objp;
{
        long  length = 0;

	length = length + xdr_length_DevShort (&objp->Ac);
	length = length + xdr_length_DevShort (&objp->Dc);

	return (length);
}





bool_t xdr_DevBpssLine(xdrs,objp)
	XDR *xdrs;
        DevBpssLine *objp;
{
	if (!xdr_float (xdrs, &objp->Set    ))  return (FALSE);
	if (!xdr_float (xdrs, &objp->Read   ))  return (FALSE);
	if (!xdr_short (xdrs, &objp->Control))  return (FALSE);
	if (!xdr_short (xdrs, &objp->Alarm  ))  return (FALSE);
	return (TRUE);
}

long
xdr_length_DevBpssLine(objp)
        DevBpssLine *objp;
{
        long  length = 0;

	length = length + xdr_length_DevFloat (&objp->Set);
	length = length + xdr_length_DevFloat (&objp->Read);
	length = length + xdr_length_DevShort (&objp->Control);
	length = length + xdr_length_DevShort (&objp->Alarm);

	return (length);
}




bool_t xdr_DevBpssReadPoint(xdrs, objp)
        XDR *xdrs;
        DevBpssReadPoint *objp;
{
        if (!xdr_DevBpssLine ( xdrs, &objp->IACinv ))  return (FALSE);
        if (!xdr_DevBpssLine ( xdrs, &objp->IACmag ))  return (FALSE);
        if (!xdr_DevBpssLine ( xdrs, &objp->IDCmag ))  return (FALSE);
        if (!xdr_DevBpssLine ( xdrs, &objp->Period ))  return (FALSE);
        if (!xdr_DevBpssLine ( xdrs, &objp->PhLag ))   return (FALSE);
	if (!xdr_float (xdrs, &objp->PhLagUI    ))  return (FALSE);
	if (!xdr_float (xdrs, &objp->VACinv    ))  return (FALSE);
	if (!xdr_float (xdrs, &objp->VDCmag    ))  return (FALSE);
	if (!xdr_float (xdrs, &objp->CapTemp    ))  return (FALSE);
	if (!xdr_float (xdrs, &objp->ChokeTemp    ))  return (FALSE);
	if (!xdr_vector(xdrs, (char *)objp->Temperature, 8, sizeof(float),
					(xdrproc_t)xdr_float)) return (FALSE);
        if (!xdr_DevBpssState( xdrs, &objp->State  ))  return (FALSE);
        if (!xdr_DevBpssState( xdrs, &objp->ExtState  ))  return (FALSE);
	if (!xdr_vector(xdrs, (char *)objp->Faults, 32, sizeof(DevBpssState),
					(xdrproc_t)xdr_DevBpssState)) return (FALSE);
        if (!xdr_short( xdrs, &objp->Master ))  return (FALSE);
        return (TRUE);
}

long
xdr_length_DevBpssReadPoint(objp)
        DevBpssReadPoint *objp;
{
        long  length = 0;

	length = length + xdr_length_DevBpssLine (&objp->IACinv);
	length = length + xdr_length_DevBpssLine (&objp->IACmag);
	length = length + xdr_length_DevBpssLine (&objp->IDCmag);
	length = length + xdr_length_DevBpssLine (&objp->Period);
	length = length + xdr_length_DevBpssLine (&objp->PhLag);

	length = length + xdr_length_DevFloat (&objp->PhLagUI);
	length = length + xdr_length_DevFloat (&objp->VACinv);
	length = length + xdr_length_DevFloat (&objp->VDCmag);
	length = length + xdr_length_DevFloat (&objp->CapTemp);
	length = length + xdr_length_DevFloat (&objp->ChokeTemp);

	length = length + (8 * xdr_length_DevFloat (&objp->Temperature[0]));

	length = length + xdr_length_DevBpssState (&objp->State);
	length = length + xdr_length_DevBpssState (&objp->ExtState);
	length = length + (32 * xdr_length_DevBpssState (&objp->Faults[0]));

	length = length + xdr_length_DevShort (&objp->Master);

	return (length);
}

==> src_release_V2.9.tar.gz: dserver/system/xdr/src/bpss_xdr.c <==
static char RcsId[] =
"@(#)$Header: /segfs/dserver/system/xdr/src/RCS/bpss_xdr.c,v 5.20 2001/01/08 12:17:35 goetz Rel $";

/*+*******************************************************************

 File:          bpss_xdr.c

 Project:       Device Servers with sun-rpc

 Description:   xdr_routines for bpss powersupply types.

 Author(s):     Jean Michel Chaize

 Original:      December 1991

$Revision: 5.20 $
$Date: 2001/01/08 12:17:35 $

$Author: goetz $

$Log: bpss_xdr.c,v $
Revision 5.20  2001/01/08 12:17:35  goetz
added patch by B.Pedersen to support querying events

Revision 5.19  2000/10/02 12:08:45  goetz
removed stderr from api_xdr.c

Revision 5.18  1999/07/08 14:10:46  goetz
changed _LPfd_set type for Linux in macros.h

Revision 5.17  1998/05/25 17:59:38  klotz
fixed C++ prototypes in api_xdr.h

Revision 5.16  1998/04/29 10:24:00  goetz
macros.h - added __STDCPP__ for HP C++ compiler (aCC)

 * Revision 5.15  97/12/01  15:16:06  15:16:06  klotz (W.D. Klotz)
 * WIN_NT_95_released_NOV_97
 * 
 * Revision 4.34  97/01/30  13:58:36  13:58:36  goetz (Andy Goetz)
 * removed dev_printdebug() from DevXdrKernel.h
 * 
 * Revision 4.33  97/01/09  10:08:41  10:08:41  goetz (Andy Goetz)
 * (xdrproc_t) castings added to maxe_xdr, ram_xdr, thc_xdr, seism_xdr
 * 
 * Revision 4.32  97/01/08  16:48:30  16:48:30  goetz (Andy Goetz)
 * Ported to Linux (2.0.9)
 * 
Revision 4.31  1996/11/18 17:28:46  goetz
Check

 * Revision 4.28  96/10/21  16:22:20  16:22:20  taurel (E.Taurel)
 * Check_in_after_port_to_OS9/ISP_2.1_and_OS9/RPC1.4
 * 
 * Revision 4.27  96/09/17  16:39:56  16:39:56  klotz (W.D. Klotz)
 * WD Klotz: tested NT build  
 * 
 * Revision 4.26  96/07/19  10:01:00  10:01:00  taurel (E.Taurel)
 * Some_change_in_macros.h_for_the_API_port_to_OS-9_Ultra_C++
 * 
 * Revision 4.25  96/06/07  16:23:04  16:23:04  meyer (J.Meyer)
 * Corrected_elif_to_else_in_macros.h
 * 
 * Revision 4.24  96/06/05  15:01:37  15:01:37  meyer (J.Meyer)
 * Corrected_macros.h
 * 
 * Revision 4.23  96/06/03  13:10:16  13:10:16  meyer (J.Meyer)
 * Cleaned-up_MSDOS_and_added_porting_options_for_Windows_NT.
 * 
 * Revision 4.22  96/05/23  11:07:24  11:07:24  taurel (E.Taurel)
 * Added_some_definitions_for_C++_in_API_xdr.h_file
 * 
 * Revision 4.21  96/05/06  18:37:36  18:37:36  meyer (J.Meyer)
 * Fortran_compatibility_for:_dev_xdr.h,macros.h,maxe_xdr.h
 * 
 * Revision 4.20  96/02/27  13:31:36  13:31:36  meyer (J.Meyer)
 * Deleted_Cross_References_To_DSAPI_Library
 * 
 * Revision 4.19  96/01/11  17:40:21  17:40:21  meyer (Jens Meyer)
 * Added_#define_PORTMAP_to_macros.h.
 * 
 * Revision 4.18  95/12/21  10:33:28  10:33:28  meyer (Jens Meyer)
 * Corrected length calculation for D_VAR_MSTATARR.
 * 
 * Revision 4.17  95/08/02  16:05:13  16:05:13  meyer (Jens Meyer)
 * Corrected DevXdrKernel.h after C++ implementation.
 * 
 * Revision 4.15  95/03/02  10:27:51  10:27:51  meyer (Jens Meyer)
 * Added D_VAR_SFRPARR type to the kernel.
 * 
 * Revision 4.14  95/02/20  09:56:39  09:56:39  meyer (Jens Meyer)
 * Passed the compilers for HPUX, SUNOS and UCC after the first windows check in.
 * 
 * Revision 4.13  95/02/10  17:18:56  17:18:56  meyer (Jens Meyer)
 * Deleted
 * 
 * Revision 4.12  95/02/01  14:26:46  14:26:46  klotz (W.D. Klotz)
 * WDK: first successfull compile of dbase, api, xdr on WIN16/3.1
 * 
 * Revision 4.11  95/01/03  13:19:18  13:19:18  meyer (Jens Meyer)
 * Repared bug in dev_cmd_query() for version 3!
 * 
 * Revision 4.10  94/12/08  15:24:50  15:24:50  meyer (Jens Meyer)
 * Changed _manager_data in API_xdr and added old version to API_xdr_vers3.
 * 
 * Revision 4.9  94/11/28  17:04:11  17:04:11  meyer (Jens Meyer)
 * Data types for compatibility with library version 3.x
 * 
 * Revision 4.8  94/08/16  16:59:27  16:59:27  meyer (Jens Meyer)
 * Corrected error in ws_xdr.h
 * 
 * Revision 4.7  94/08/16  16:34:23  16:34:23  meyer (Jens Meyer)
 * Added define for MAX_RESOURCE_FIELD_LENGTH to macros.h
 * 
 * Revision 4.6  94/08/12  15:07:37  15:07:37  meyer (Jens Meyer)
 * Added valriable arguments to all API RPC structures.
 * 
 * Revision 4.5  94/07/20  18:15:39  18:15:39  meyer (Jens Meyer)
 * Changed include files in macros.h!
 * 
 * Revision 4.4  94/07/20  08:55:38  08:55:38  meyer (Jens Meyer)
 * All XDR functions with prototypes!
 * 
 * Revision 4.3  94/07/18  18:50:49  18:50:49  meyer (Jens Meyer)
 * Had to change macros.h, because #define must be in the first column!
 * 
 * Revision 4.2  94/07/18  18:22:05  18:22:05  meyer (Jens Meyer)
 * First test with PC macros for the XDR kernel.
 * 
 * Revision 4.1  94/05/02  10:50:42  10:50:42  meyer (Jens Meyer)
 * For Security System without connection count.
 * 
 * Revision 4.0  94/03/14  18:17:26  18:17:26  meyer (Jens Meyer)
 * Library version with Security System.
 * 
 * Revision 3.50  94/03/12  14:36:20  14:36:20  meyer (Jens Meyer)
 * Changed API xdr structures for security.
 * 
 * Revision 3.35  94/03/03  10:52:04  10:52:04  taurel (Emmanuel TAUREL)
 * Added unsigned long array type in the XDRkernel
 * 
 * Revision 3.34  94/03/03  10:28:57  10:28:57  taurel (Emmanuel TAUREL)
 * Added the unsigned long array type in
 * XDR kernel (LC and ET).
 * 
 * Revision 3.33  94/01/12  16:34:19  16:34:19  meyer (Jens Meyer)
 * Global XDR type array for data collector access
 * 
 * Revision 3.31  93/12/02  09:38:53  09:38:53  meyer (Jens Meyer)
 * New release with small XDR data type kernel.
 * 
 * Revision 1.1  93/11/16  10:55:03  10:55:03  meyer (Jens Meyer)
 * Initial revision
 * 

Copyright (c) 1990 by European Synchrotron Radiation Facility,
		      Grenoble, France
*******************************************************************-*/

#include <dev_xdr.h>
#include <bpss_xdr.h>


bool_t xdr_DevStateIndic(xdrs, objp)
	XDR *xdrs;
	DevStateIndic *objp;
{
	if (!xdr_short(xdrs, &objp->State))  return (FALSE);
	if (!xdr_short(xdrs, &objp->Indic))  return (FALSE);
	return (TRUE);
}

long
xdr_length_DevStateIndic(objp)
	DevStateIndic *objp;
{
        long  length = 0;

	length = length + xdr_length_DevShort (&objp->State);
	length = length + xdr_length_DevShort (&objp->Indic);

	return (length);
}




bool_t xdr_DevBpssState(xdrs, objp)
        XDR *xdrs;
	DevBpssState *objp;
{
        if (!xdr_short(xdrs, &objp->Ac))  return (FALSE);
        if (!xdr_short(xdrs, &objp->Dc))  return (FALSE);
        return (TRUE);
}

long
xdr_length_DevBpssState(objp)
	DevBpssState *objp;
{
        long  length = 0;

	length = length + xdr_length_DevShort (&objp->Ac);
	length = length + xdr_length_DevShort (&objp->Dc);

	return (length);
}





bool_t xdr_DevBpssLine(xdrs,objp)
	XDR *xdrs;
        DevBpssLine *objp;
{
	if (!xdr_float (xdrs, &objp->Set    ))  return (FALSE);
	if (!xdr_float (xdrs, &objp->Read   ))  return (FALSE);
	if (!xdr_short (xdrs, &objp->Control))  return (FALSE);
	if (!xdr_short (xdrs, &objp->Alarm  ))  return (FALSE);
	return (TRUE);
}

long
xdr_length_DevBpssLine(objp)
        DevBpssLine *objp;
{
        long  length = 0;

	length = length + xdr_length_DevFloat (&objp->Set);
	length = length + xdr_length_DevFloat (&objp->Read);
	length = length + xdr_length_DevShort (&objp->Control);
	length = length + xdr_length_DevShort (&objp->Alarm);

	return (length);
}




bool_t xdr_DevBpssReadPoint(xdrs, objp)
        XDR *xdrs;
        DevBpssReadPoint *objp;
{
        if (!xdr_DevBpssLine ( xdrs, &objp->IACinv ))  return (FALSE);
        if (!xdr_DevBpssLine ( xdrs, &objp->IACmag ))  return (FALSE);
        if (!xdr_DevBpssLine ( xdrs, &objp->IDCmag ))  return (FALSE);
        if (!xdr_DevBpssLine ( xdrs, &objp->Period ))  return (FALSE);
        if (!xdr_DevBpssLine ( xdrs, &objp->PhLag ))   return (FALSE);
	if (!xdr_float (xdrs, &objp->PhLagUI    ))  return (FALSE);
	if (!xdr_float (xdrs, &objp->VACinv    ))  return (FALSE);
	if (!xdr_float (xdrs, &objp->VDCmag    ))  return (FALSE);
	if (!xdr_float (xdrs, &objp->CapTemp    ))  return (FALSE);
	if (!xdr_float (xdrs, &objp->ChokeTemp    ))  return (FALSE);
	if (!xdr_vector(xdrs, (char *)objp->Temperature, 8, sizeof(float),
					(xdrproc_t)xdr_float)) return (FALSE);
        if (!xdr_DevBpssState( xdrs, &objp->State  ))  return (FALSE);
        if (!xdr_DevBpssState( xdrs, &objp->ExtState  ))  return (FALSE);
	if (!xdr_vector(xdrs, (char *)objp->Faults, 32, sizeof(DevBpssState),
					(xdrproc_t)xdr_DevBpssState)) return (FALSE);
        if (!xdr_short( xdrs, &objp->Master ))  return (FALSE);
        return (TRUE);
}

long
xdr_length_DevBpssReadPoint(objp)
        DevBpssReadPoint *objp;
{
        long  length = 0;

	length = length + xdr_length_DevBpssLine (&objp->IACinv);
	length = length + xdr_length_DevBpssLine (&objp->IACmag);
	length = length + xdr_length_DevBpssLine (&objp->IDCmag);
	length = length + xdr_length_DevBpssLine (&objp->Period);
	length = length + xdr_length_DevBpssLine (&objp->PhLag);

	length = length + xdr_length_DevFloat (&objp->PhLagUI);
	length = length + xdr_length_DevFloat (&objp->VACinv);
	length = length + xdr_length_DevFloat (&objp->VDCmag);
	length = length + xdr_length_DevFloat (&objp->CapTemp);
	length = length + xdr_length_DevFloat (&objp->ChokeTemp);

	length = length + (8 * xdr_length_DevFloat (&objp->Temperature[0]));

	length = length + xdr_length_DevBpssState (&objp->State);
	length = length + xdr_length_DevBpssState (&objp->ExtState);
	length = length + (32 * xdr_length_DevBpssState (&objp->Faults[0]));

	length = length + xdr_length_DevShort (&objp->Master);

	return (length);
}
